NuRadioReco\.modules\.phasedarray package
=========================================

Submodules
----------

NuRadioReco\.modules\.phasedarray\.triggerSimulator module
----------------------------------------------------------

.. automodule:: NuRadioReco.modules.phasedarray.triggerSimulator
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules.phasedarray
    :members:
    :undoc-members:
    :show-inheritance:
